@@ -22,7 +22,7 @@ from pde import FieldCollection, PDEBase, UnitGrid
 class FitzhughNagumoPDE(PDEBase):
     """FitzHugh–Nagumo model with diffusive coupling"""
 
-    def __init__(self, stimulus=0.5, τ=10, a=0, b=0, bc="natural"):
+    def __init__(self, stimulus=0.5, τ=10, a=0, b=0, bc="auto_periodic_neumann"):
         self.bc = bc
         self.stimulus = stimulus
         self.τ = τ
