@@ -5,9 +5,7 @@ Stochastic simulation
 This example illustrates how a stochastic simulation can be done.
 """
 
-from pde import (KPZInterfacePDE, UnitGrid, ScalarField, MemoryStorage,
-                 plot_kymograph)
-
+from pde import KPZInterfacePDE, MemoryStorage, ScalarField, UnitGrid, plot_kymograph
 
 grid = UnitGrid([64])  # generate grid
 state = ScalarField.random_harmonic(grid)  # generate initial condition
