@@ -23,7 +23,12 @@ from .scalar import ScalarField
 
 
 class FieldCollection(FieldBase):
-    """Collection of fields defined on the same grid"""
+    """Collection of fields defined on the same grid
+
+    Note that all fields in the same collection must have the same data type. This might
+    lead to upcasting, where for instance a combination of a real-valued and a
+    complex-valued field will be both stored as complex fields.
+    """
 
     def __init__(
         self,
@@ -338,19 +343,25 @@ class FieldCollection(FieldBase):
         grid: GridBase,
         vmin: float = 0,
         vmax: float = 1,
+        *,
         label: Optional[str] = None,
         labels: Optional[Sequence[str]] = None,
     ) -> FieldCollection:
         """create scalar fields with random values between `vmin` and `vmax`
 
         Args:
-            num_fields (int): The number of fields to create
+            num_fields (int):
+                The number of fields to create
             grid (:class:`~pde.grids.base.GridBase`):
                 Grid defining the space on which the fields are defined
-            vmin (float): Smallest random value
-            vmax (float): Largest random value
-            label (str, optional): Name of the field collection
-            labels (list of str, optional): Names of the individual fields
+            vmin (float):
+                Lower bound. Can be complex to create complex fields
+            vmax (float):
+                Upper bound. Can be complex to create complex fields
+            label (str, optional):
+                Name of the field collection
+            labels (list of str, optional):
+                Names of the individual fields
         """
         if labels is None:
             labels = [None] * num_fields  # type: ignore
@@ -384,6 +395,8 @@ class FieldCollection(FieldBase):
             if key == "fields":
                 fields = [f.attributes_serialized for f in self.fields]
                 results[key] = json.dumps(fields)
+            elif key == "dtype":
+                results[key] = json.dumps(value.str)
             else:
                 results[key] = json.dumps(value)
         return results
@@ -413,7 +426,6 @@ class FieldCollection(FieldBase):
     def copy(
         self: FieldCollection,
         *,
-        # data: Union[ArrayLike, str] = "copy",
         label: str = None,
         dtype=None,
     ) -> FieldCollection:
@@ -603,8 +615,8 @@ class FieldCollection(FieldBase):
             {PLOT_ARGS}
             subplot_args (list):
                 Additional arguments for the specific subplots. Should be a list with a
-                dictionary of arguments for each subplot. Supplying an empty allows to
-                keep the default setting of specific subplots.
+                dictionary of arguments for each subplot. Supplying an empty dict allows
+                to keep the default setting of specific subplots.
             \**kwargs:
                 All additional keyword arguments are forwarded to the actual plotting
                 function of all subplots.
