@@ -299,7 +299,7 @@ class VectorField(DataFieldBase):
                         # correctly and we thus had to use this work-around
                         return np.einsum("i...,i...->...", a, b)  # type: ignore
                     else:
-                        return np.einsum("i...,i...->...", a, b, out=out)  # type: ignore
+                        return np.einsum("i...,i...->...", a, b, out=out)
 
                 elif a.shape == b.shape[1:]:
                     # dot product between vector and tensor
@@ -309,7 +309,7 @@ class VectorField(DataFieldBase):
                         # correctly and we thus had to use this work-around
                         return np.einsum("i...,ij...->j...", a, b)  # type: ignore
                     else:
-                        return np.einsum("i...,ij...->j...", a, b, out=out)  # type: ignore
+                        return np.einsum("i...,ij...->j...", a, b, out=out)
 
                 else:
                     raise ValueError(f"Unsupported shapes ({a.shape}, {b.shape})")
@@ -451,7 +451,7 @@ class VectorField(DataFieldBase):
                     # correctly and we thus had to use this work-around
                     return np.einsum("i...,j...->ij...", a, b)  # type: ignore
                 else:
-                    return np.einsum("i...,j...->ij...", a, b, out=out)  # type: ignore
+                    return np.einsum("i...,j...->ij...", a, b, out=out)
 
         else:
             raise ValueError(f"Undefined backend `{backend}")
@@ -551,9 +551,9 @@ class VectorField(DataFieldBase):
                 Choose the method to use. Possible  choices are `norm`, `max`, `min`,
                 `squared_sum`, `norm_squared`, or an integer specifying which component
                 is returned (indexing starts at `0`). The default value `auto` picks the
-                method based on the dimension of the space: The first (and only)
-                component is returned for one-dimensional spaces, while the norm of the
-                vector is returned otherwise.
+                method automatically: The first (and only) component is returned for
+                real fields on one-dimensional spaces, while the norm of the vector is
+                returned otherwise.
             label (str, optional):
                 Name of the returned field
 
@@ -562,7 +562,10 @@ class VectorField(DataFieldBase):
             applying the operation
         """
         if scalar == "auto":
-            scalar = "norm" if self.grid.dim > 1 else 0
+            if self.grid.dim > 1 or np.iscomplexobj(self.data):
+                scalar = "norm"
+            else:
+                scalar = 0  # return the field unchanged
 
         if isinstance(scalar, int):
             data = self.data[scalar]
