@@ -394,7 +394,7 @@ class CartesianGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equals
 
     @fill_in_docstring
     def get_boundary_conditions(
-        self, bc: "BoundariesData" = "natural", rank: int = 0
+        self, bc: "BoundariesData" = "auto_periodic_neumann", rank: int = 0
     ) -> "Boundaries":
         """constructs boundary conditions from a flexible data format
 
@@ -493,7 +493,7 @@ class UnitGrid(CartesianGridBase):
             return np.zeros((0, self.dim))
         if cells.shape[-1] != self.dim:
             raise DimensionError(f"Array of shape {cells.shape} cannot denote cells")
-        return cells + 0.5  # type: ignore
+        return cells + 0.5
 
     def point_to_cell(self, points: np.ndarray) -> np.ndarray:
         """Determine cell(s) corresponding to given point(s)
