@@ -45,11 +45,11 @@ def volume_from_radius(radius: TNumArr, dim: int) -> TNumArr:
         float or :class:`~numpy.ndarray`: Volume of the sphere
     """
     if dim == 1:
-        return 2 * radius  # type: ignore
+        return 2 * radius
     elif dim == 2:
-        return π * radius ** 2  # type: ignore
+        return π * radius ** 2
     elif dim == 3:
-        return PI_43 * radius ** 3  # type: ignore
+        return PI_43 * radius ** 3
     else:
         raise NotImplementedError(f"Cannot calculate the volume in {dim} dimensions")
 
@@ -437,7 +437,9 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
             return rs
 
     @fill_in_docstring
-    def get_boundary_conditions(self, bc="natural", rank: int = 0) -> "Boundaries":
+    def get_boundary_conditions(
+        self, bc="auto_periodic_neumann", rank: int = 0
+    ) -> "Boundaries":
         """constructs boundary conditions from a flexible data format.
 
         If the inner boundary condition for a grid without a hole is not specified, this
@@ -468,7 +470,7 @@ class SphericalSymGridBase(GridBase, metaclass=ABCMeta):  # lgtm [py/missing-equ
             # a full boundary instance is given
             return bc
 
-        if bc == "natural" or bc == "auto_periodic_neumann":
+        if bc == "auto_periodic_neumann" or bc == "auto_periodic_neumann":
             # a simple value is given => use it for the outer boundary
             return Boundaries.from_data(self, "derivative", rank=rank)
         elif bc == "auto_periodic_dirichlet":
