@@ -38,7 +38,7 @@ class KPZInterfacePDE(PDEBase):
         nu: float = 0.5,
         lmbda: float = 1,
         noise: float = 0,
-        bc: BoundariesData = "natural",
+        bc: BoundariesData = "auto_periodic_neumann",
     ):
         r"""
         Args:
