@@ -37,7 +37,7 @@ class KuramotoSivashinskyPDE(PDEBase):
         self,
         nu: float = 1,
         noise: float = 0,
-        bc: BoundariesData = "natural",
+        bc: BoundariesData = "auto_periodic_neumann",
         bc_lap: BoundariesData = None,
     ):
         r"""
