@@ -42,7 +42,7 @@ class PDE(PDEBase):
         self,
         rhs: Dict[str, str],
         noise: ArrayLike = 0,
-        bc: BoundariesData = "natural",
+        bc: BoundariesData = "auto_periodic_neumann",
         bc_ops: Dict[str, BoundariesData] = None,
         user_funcs: Dict[str, Any] = None,
         consts: Dict[str, Any] = None,
@@ -63,8 +63,9 @@ class PDE(PDEBase):
                 be specified with their full name, i.e., `laplace` for a scalar
                 Laplacian and `vector_laplace` for a Laplacian operating on a vector
                 field. Moreover, the dot product between two vector fields can be
-                denoted by using `dot(field1, field2)` in the expression, while an outer
-                product is calculated using `outer(field1, field2)`.
+                denoted by using `dot(field1, field2)` in the expression, an outer
+                product is calculated using `outer(field1, field2)`, and
+                `integral(field)` denotes an integral over a field.
             noise (float or :class:`~numpy.ndarray`):
                 Magnitude of additive Gaussian white noise. The default value of zero
                 implies deterministic partial differential equations will be solved.
@@ -156,14 +157,14 @@ class PDE(PDEBase):
         self.consts = consts
         self.explicit_time_dependence = explicit_time_dependence
         self.complex_valued = complex_valued
-        operators = frozenset().union(*self._operators.values())  # type: ignore
+        operators = frozenset().union(*self._operators.values())
 
         # setup boundary conditions
         if bc_ops is None:
             bcs = {"*:*": bc}
         else:
             bcs = dict(bc_ops)
-            if "*:*" in bcs and bc != "natural":
+            if "*:*" in bcs and bc != "auto_periodic_neumann":
                 self._logger.warning("Found default BCs in `bcs` and `bc_ops`")
             bcs["*:*"] = bc  # append default boundary conditions
 
@@ -321,7 +322,7 @@ class PDE(PDEBase):
             """wrapper that inserts the extra arguments and initialized bc_args"""
             bc_args = NumbaDict()  # args for differential operators
             bc_args["t"] = args[-1]  # pass time to differential operators
-            return func_inner(*args, None, bc_args, *extra_args)
+            return func_inner(*args, None, bc_args, *extra_args)  # type: ignore
 
         return rhs_func
 
@@ -384,7 +385,7 @@ class PDE(PDEBase):
                 rhs.consts[name] = value
 
         # obtain functions used in the expression
-        ops_general = {}
+        ops_general: Dict[str, Callable] = {}
 
         # create special operators if necessary
         if "dot" in self.diagnostics["operators"]:  # type: ignore
@@ -393,13 +394,17 @@ class PDE(PDEBase):
             ops_general["dot"] = VectorField(state.grid).make_dot_operator(backend)
 
         if "inner" in self.diagnostics["operators"]:  # type: ignore
-            # synonym for dot product operator
+            # inner is a synonym for dot product operator
             ops_general["inner"] = VectorField(state.grid).make_dot_operator(backend)
 
         if "outer" in self.diagnostics["operators"]:  # type: ignore
-            # synonym for dot product operator
+            # generate an operator that calculates an outer product
             ops_general["outer"] = VectorField(state.grid).make_outer_prod_operator()
 
+        if "integral" in self.diagnostics["operators"]:  # type: ignore
+            # add an operator that integrates a field
+            ops_general["integral"] = state.grid.make_integrator()
+
         # Create the right hand sides for all variables. It is important to do this in a
         # separate function, so the closures work reliably
         cache["rhs_funcs"] = [
