@@ -368,7 +368,7 @@ class ExplicitSolver(SolverBase):
                 # estimate the maximal error
                 error = 0.0
                 for i in range(state_data.size):
-                    error_local = abs(
+                    error_local: float = abs(
                         r1 * k1.flat[i]
                         + r3 * k3.flat[i]
                         + r4 * k4.flat[i]
@@ -433,7 +433,7 @@ class ExplicitSolver(SolverBase):
         if dt is None:
             dt = 1e-3
             if not self.adaptive:
-                self._logger.warn(
+                self._logger.warning(
                     "Explicit stepper with a fixed time step did not receive any "
                     f"initial value for `dt`. Using dt={dt}, but specifying a value or "
                     "enabling adaptive stepping is advisable."
